var indexSectionsWithContent =
{
  0: "acdefgiklmnopqrstuw",
  1: "s",
  2: "q",
  3: "cdegilmoprstw",
  4: "acdfgklmnpstu",
  5: "q"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Pages"
};

